/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.sample

import android.app.Application
import android.content.Context
import com.kakao.sdk.common.KakaoSdk
import com.kakao.sdk.common.model.ServerHosts
import com.kakao.sdk.partner.KakaoPhase
import com.kakao.sdk.partner.withPhase

class PartnerApplication : Application() {
    override fun onCreate() {
        super.onCreate()

        val preferences = getSharedPreferences("default", Context.MODE_PRIVATE)
        val currentPhase = KakaoPhase.fromName(
            preferences.getString("phase", KakaoPhase.PRODUCTION.phaseName) as String
        )
        KakaoSdk.init(
            context = this,
            appKey = getKakaoAppKey(currentPhase),
            hosts = ServerHosts.withPhase(currentPhase),
            loggingEnabled = true
        )
    }

    private fun getKakaoAppKey(phase: KakaoPhase): String =
        when (phase) {
            KakaoPhase.DEV -> getString(R.string.dev_app_key)
            KakaoPhase.SANDBOX -> getString(R.string.sandbox_app_key)
            KakaoPhase.CBT, KakaoPhase.PRODUCTION -> getString(R.string.production_app_key)
        }
}